__title__ = "seedr"
__description__ = "Unofficial API wrapper for seedr.cc ."
__url__ = "https://github.com/AnjanaMadu/SeedrAPI"
__version__ = "1.2.2"
__author__ = "Anjana Madu"
__author_email__ = "hello@anjanamadu.net"
__license__ = "GPL 3.0"
__copyright__ = "Copyright 2022 Anjana Madu"
